## minified zlib: 

A lot of zlib original files are deleted here
see  http://zlib.net  or  https://github.com/madler/zlib.git  for the original version

This version of zlib is intended for use with the libvoxel library only.

### To compile type, in a Linux terminal: 

    mkdir build; cd build; cmake .. ; make


### ChangeLog:
 - contrib/iostream3/zfstream.h is added to the zlib CMakeLists.txt.
